#!/usr/bin/env python3
import os
import yaml

factory_params_filename = os.environ['HELLO_FLEET_PATH']+'/'+os.environ['HELLO_FLEET_ID']+'/stretch_re1_factory_params.yaml'

with open(factory_params_filename, 'r') as fid:
    factory_params = yaml.safe_load(fid)
    robot_info = factory_params['robot']
    batch_name = robot_info['batch_name']
    serial_number = robot_info['serial_no']

batch_name_string = 'Stretch Batch Name: {0}'.format(batch_name)
serial_number_string = 'Stretch Serial Number: {0}'.format(serial_number)

print(batch_name_string)
print(serial_number_string)



#!/usr/bin/env python
from __future__ import print_function
import stretch_body.robot as robot
import argparse
import stretch_body.hello_utils as hu
hu.print_stretch_re_use()

parser=argparse.ArgumentParser(description='Calibrate position for all robot joints')
args=parser.parse_args()

r=robot.Robot()
r.startup()
r.home()
r.stop()



#!/usr/bin/env python
from __future__ import print_function
import os
import stretch_body.hello_utils as hu
hu.print_stretch_re_use()

os.system('pactl set-default-sink alsa_output.pci-0000_00_1f.3.analog-stereo')
os.system('amixer set Master 80%')
os.system('paplay --device=alsa_output.pci-0000_00_1f.3.analog-stereo /usr/share/sounds/ubuntu/stereo/desktop-login.ogg')




#!/usr/bin/env python
from __future__ import print_function
import stretch_body.robot as rb
import stretch_body.hello_utils as hu
hu.print_stretch_re_use()

robot = rb.Robot()
robot.startup()
robot.stow()
robot.stop()
